# Topsis-Ujjwal-101916067
It takes csv file with the model's information, weights, impacts as input and returns the ranking of the model based on the certain algorithm.

## Installation
```pip install Topsis-Ujjwal-101916067```

## How to use it?
'''
python <python_file> </python_file><input_csv_file> <string_of_weights> <string_of_impacts> <name_of_output_file>
'''
'''
>> python 101916067.py 101916067-data.csv "1,1,1,1" "+,+,-,+" 101916067-output.csv
'''


## License

© 2022 Ujjwal-Madaan

This repository is licensed under the MIT license. See LICENSE for details.